@@ -29,22 +29,21 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.StringTokenizer;
 
-import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
-import javax.servlet.ServletException;
-import javax.servlet.ServletOutputStream;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.WriteListener;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpServletResponseWrapper;
-import javax.servlet.http.MappingMatch;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.FilterConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletOutputStream;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.WriteListener;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponseWrapper;
+import jakarta.servlet.http.MappingMatch;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.buf.StringUtils;
-import org.apache.tomcat.util.http.Method;
 
 /**
  * <p>
@@ -166,10 +165,10 @@ import org.apache.tomcat.util.http.Method;
  * <h4>
  * {@code ExpiresExcludedResponseStatusCodes}</h4>
  * <p>
- * This directive defines the HTTP response status codes for which the
+ * This directive defines the http response status codes for which the
  * {@code ExpiresFilter} will not generate expiration headers. By default, the
  * {@code 304} status code (&quot;{@code Not modified}&quot;) is skipped. The
- * value is a comma separated list of HTTP status codes.
+ * value is a comma separated list of http status codes.
  * </p>
  * <p>
  * This directive is useful to ease usage of {@code ExpiresDefault} directive.
@@ -333,7 +332,7 @@ import org.apache.tomcat.util.http.Method;
  * </p>
  * <p>
  * To trap the &#x27;before write response body&#x27; event, the
- * {@code ExpiresFilter} wraps the HTTP servlet response&#x27;s writer and
+ * {@code ExpiresFilter} wraps the http servlet response&#x27;s writer and
  * outputStream to intercept calls to the methods {@code write()},
  * {@code print()}, {@code close()} and {@code flush()}. For empty response
  * body (e.g. empty files), the {@code write()}, {@code print()},
@@ -446,7 +445,7 @@ public class ExpiresFilter extends FilterBase {
     /**
      * Duration unit
      */
-    public enum DurationUnit {
+    protected enum DurationUnit {
         DAY(Calendar.DAY_OF_YEAR),
         HOUR(Calendar.HOUR),
         MINUTE(Calendar.MINUTE),
@@ -511,14 +510,14 @@ public class ExpiresFilter extends FilterBase {
      * ({@link StartingPoint#ACCESS_TIME}) or the last time the HTML-page/servlet-response was modified (
      * {@link StartingPoint#LAST_MODIFICATION_TIME}).
      */
-    public enum StartingPoint {
+    protected enum StartingPoint {
         ACCESS_TIME,
         LAST_MODIFICATION_TIME
     }
 
     /**
      * <p>
-     * Wrapping extension of the {@link HttpServletResponse} to wrap the "Start Write Response Body" event.
+     * Wrapping extension of the {@link HttpServletResponse} to yrap the "Start Write Response Body" event.
      * </p>
      * <p>
      * For performance optimization : this extended response holds the {@link #lastModifiedHeader} and
@@ -529,12 +528,12 @@ public class ExpiresFilter extends FilterBase {
     public class XHttpServletResponse extends HttpServletResponseWrapper {
 
         /**
-         * Value of the {@code Cache-Control} HTTP response header if it has been set.
+         * Value of the {@code Cache-Control} http response header if it has been set.
          */
         private String cacheControlHeader;
 
         /**
-         * Value of the {@code Last-Modified} HTTP response header if it has been set.
+         * Value of the {@code Last-Modified} http response header if it has been set.
          */
         private long lastModifiedHeader;
 
@@ -569,12 +568,8 @@ public class ExpiresFilter extends FilterBase {
         @Override
         public void addHeader(String name, String value) {
             super.addHeader(name, value);
-            if (HEADER_CACHE_CONTROL.equalsIgnoreCase(name)) {
-                if (cacheControlHeader == null) {
-                    cacheControlHeader = value;
-                } else {
-                    cacheControlHeader = StringUtils.join(cacheControlHeader, value);
-                }
+            if (HEADER_CACHE_CONTROL.equalsIgnoreCase(name) && cacheControlHeader == null) {
+                cacheControlHeader = value;
             }
         }
 
@@ -1032,7 +1027,7 @@ public class ExpiresFilter extends FilterBase {
     private static final String PARAMETER_EXPIRES_EXCLUDED_RESPONSE_STATUS_CODES = "ExpiresExcludedResponseStatusCodes";
 
     /**
-     * Convert a comma-delimited list of numbers into an {@code int[]}.
+     * Convert a comma delimited list of numbers into an {@code int[]}.
      *
      * @param commaDelimitedInts can be {@code null}
      *
@@ -1081,7 +1076,7 @@ public class ExpiresFilter extends FilterBase {
     }
 
     /**
-     * Convert an array of ints into a comma-delimited string
+     * Convert an array of ints into a comma delimited string
      *
      * @param ints The int array
      *
@@ -1109,7 +1104,7 @@ public class ExpiresFilter extends FilterBase {
      * @return {@code true} if the given {@code str} is {@code null} or has a zero characters length.
      */
     protected static boolean isEmpty(String str) {
-        return str == null || str.isEmpty();
+        return str == null || str.length() == 0;
     }
 
     /**
@@ -1216,27 +1211,6 @@ public class ExpiresFilter extends FilterBase {
     }
 
 
-    /**
-     * Returns the expiration date of the given {@link XHttpServletResponse} or {@code null} if no expiration date has
-     * been configured for the declared content type.
-     * <p>
-     * {@code protected} for extension.
-     *
-     * @param response The wrapped HTTP response
-     *
-     * @return the expiration date
-     *
-     * @see HttpServletResponse#getContentType()
-     *
-     * @deprecated Will be removed in Tomcat 10. Use
-     *                 {@link #getExpirationDate(HttpServletRequest, XHttpServletResponse)}
-     */
-    @Deprecated
-    protected Date getExpirationDate(XHttpServletResponse response) {
-        return getExpirationDate((HttpServletRequest) null, response);
-    }
-
-
     /**
      * Returns the expiration date of the given {@link XHttpServletResponse} or {@code null} if no expiration date has
      * been configured for the declared content type.
@@ -1394,7 +1368,8 @@ public class ExpiresFilter extends FilterBase {
                     ExpiresConfiguration expiresConfiguration = parseExpiresConfiguration(value);
                     this.expiresConfigurationByContentType.put(contentType, expiresConfiguration);
                 } else if (name.equalsIgnoreCase(PARAMETER_EXPIRES_DEFAULT)) {
-                    this.defaultExpiresConfiguration = parseExpiresConfiguration(value);
+                    ExpiresConfiguration expiresConfiguration = parseExpiresConfiguration(value);
+                    this.defaultExpiresConfiguration = expiresConfiguration;
                 } else if (name.equalsIgnoreCase(PARAMETER_EXPIRES_EXCLUDED_RESPONSE_STATUS_CODES)) {
                     this.excludedResponseStatusCodes = commaDelimitedListToIntArray(value);
                 } else {
@@ -1425,7 +1400,7 @@ public class ExpiresFilter extends FilterBase {
 
         // Don't add cache headers unless the request is a GET or a HEAD request
         String method = request.getMethod();
-        if (!Method.GET.equals(method) && !Method.HEAD.equals(method)) {
+        if (!"GET".equals(method) && !"HEAD".equals(method)) {
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("expiresFilter.invalidMethod", request.getRequestURI(), method));
             }
